#!/bin/bash

dir=`dirname $0`

# Use common Linux directory to avoid loading su much data
$dir/set_linux_dir.sh ..\\/linux-src
